<?php
/**
 * Plugin Name: WP-Twitter Retweet Button
 * Plugin URI: http://blog.ppfeufer.de/wordpress-plugin-wp-twitter-button/
 * Description: This plugin will install the WP Twitter Button widget for each of your blog posts.
 * Version: 1.2.0
 * Author: H.-Peter Pfeufer
 * Author URI: http://ppfeufer.de
 */

function wp_twitter_options() {
	add_menu_page('WP-Twitter', 'WP-Twitter', 8, basename(__FILE__), 'wp_twitter_options_page');
	add_submenu_page(basename(__FILE__), 'Settings', 'Settings', 8, basename(__FILE__), 'wp_twitter_options_page');
}

/**
 * Generate the iFrame render of the button
 */
function wp_twitter_generate_button() {
	$url = get_permalink();
	$tweettext = wp_twitter_get_tweettext();

	$button = '<div class="wp_twitter_button" style="' . get_option('wp_twitter_style') . '">';
	$button .= '<a href="http://twitter.com/share" class="twitter-share-button" data-url="' . $url . '" data-count="' . get_option('wp_twitter_version') . '" data-via="' . get_option('wp_twitter_source') . '" data-lang="' . get_option('wp_twitter_language') . '" ' . $tweettext . '>Tweet</a>';
	$button .= '<script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>';
	$button .= '</div>';

	return $button;
}

/**
 * Generates the image button
 */
function wp_twitter_generate_static_button() {
	if(get_post_status($post->ID) == 'publish') {
		$url = get_permalink();
		$tweettext = wp_twitter_get_tweettext();

		return '<div class="wp_twitter_button" style="' . get_option('wp_twitter_style') . '">
					<a href="http://twitter.com/share" class="twitter-share-button" data-url="' . $url . '" data-count="' . get_option('wp_twitter_version') . '" data-via="' . get_option('wp_twitter_source') . '" data-lang="' . get_option('wp_twitter_language') . '" ' . $tweettext . '>Tweet</a>
					<script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>
				</div>';
	} else {
		return;
	}
}

function wp_twitter_get_tweettext() {
	$tweettext = '';
	if (get_option('wp_twitter_tweettext') == 'own') {
		$tweettext = 'data-text="' . get_option('wp_twitter_tweettext_owntext') . '"';
	} else {
		if (get_option('wp_twitter_display_front') == '1' && is_home()) {
			$tweettext = 'data-text="' . the_title('', '', false) . ' | ' . get_bloginfo('name') . '"';
		} else {
			return;
		}
	}

	return $tweettext;
}

/**
 * Gets run when the content is loaded in the loop
 */
function wp_twitter_update($content) {

	global $post;

	// add the manual option, code added by kovshenin
	if(get_option('wp_twitter_where') == 'manual') {
		return $content;
	}

	// is it a page
	if(get_option('wp_twitter_display_page') == null && is_page()) {
		return $content;
	}

	// are we on the front page
	if(get_option('wp_twitter_display_front') == null && is_home()) {
		return $content;
	}

	if (is_feed()) {
		$button = wp_twitter_generate_static_button();
		$where = 'wp_twitter_rss_where';
	} else {
		$button = wp_twitter_generate_button();
		$where = 'wp_twitter_where';
	}

	// are we just using the shortcode
	if(get_option($where) == 'shortcode') {
		return str_replace('[wp_twitter]', $button, $content);
	} else {
		// if we have switched the button off
		if(get_post_meta($post->ID, 'wp_twitter') == null) {
			if(get_option($where) == 'beforeandafter') {
				// adding it before and after
				return $button . $content . $button;
			} else if(get_option($where) == 'before') {
				// just before
				return $button . $content;
			} else {
				// just after
				return $content . $button;
			}
		} else {
			// not at all
			return $content;
		}
	}
}

// Manual output
function wp_twitter() {
	if(get_option('wp_twitter_where') == 'manual') {
		return wp_twitter_generate_button();
	} else {
		return false;
	}
}

// Remove the filter excerpts
function wp_twitter_remove_filter($content) {
	if(!is_feed()) {
		remove_action('the_content', 'wp_twitter_update');
	}
	return $content;
}

/**
 * Adds a wp_twitter-title meta title, provides a much more accurate title for the button
 */
function wp_twitter_head() {
	// if its a post page
	if(is_single()) {
		global $post;
		$title = get_the_title($post->ID);
		echo '<meta name="wp_twitter-title" content="' . strip_tags($title) . '" />';
	}
}

function wp_twitter_options_page() {
	?>
<div class="wrap">
	<div class="icon32" id="icon-options-general"><br /></div>
	<h2>Settings for WP Twitter Button</h2>
	<p>This plugin will install the WP Twitter Button widget for each of your blog posts.</p>
	<form method="post" action="options.php">
		<?php
		// New way of setting the fields, for WP 2.7 and newer
		if(function_exists('settings_fields')) {
			settings_fields('wp_twitter-options');
		} else {
			wp_nonce_field('update-options');
			?>
			<input type="hidden" name="action" value="update" />
			<input type="hidden" name="page_options" value="wp_twitter_where,wp_twitter_style,wp_twitter_version,wp_twitter_display_page,wp_twitter_display_front,wp_twitter_display_feed,wp_twitter_source,wp_twitter_space,wp_twitter_hashtags,wp_twitter_hashtags_tags" />
			<?php
		}
		?>
		<table class="form-table">
			<tr>
				<th scope="row" valign="top">Display</th>
				<td>
					<div>
						<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_page') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_page" id="wp_twitter_display_page" group="wp_twitter_display" />
						<label for="wp_twitter_display_page">Display the button on pages</label>
					</div>
					<div>
						<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_front') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_front" id="wp_twitter_display_front" group="wp_twitter_display" />
						<label for="wp_twitter_display_front">Display the button on front page (home)</label>
					</div>
					<div>
						<input type="checkbox" value="1" <?php if(get_option('wp_twitter_display_feed') == '1') echo 'checked="checked"'; ?> name="wp_twitter_display_feed" id="wp_twitter_display_feed" group="wp_twitter_display" />
						<label for="wp_twitter_display_feed">Display the button on rss-feed</label>
					</div>
				</td>
			</tr>
			<tr>
				<th scope="row" valign="top">Position</th>
				<td>
					<select name="wp_twitter_where">
						<option <?php if(get_option('wp_twitter_where') == 'before') echo 'selected="selected"'; ?> value="before">Before</option>
						<option <?php if(get_option('wp_twitter_where') == 'after') echo 'selected="selected"'; ?> value="after">After</option>
						<option <?php if(get_option('wp_twitter_where') == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter">Before and After</option>
						<option <?php if(get_option('wp_twitter_where') == 'shortcode') echo 'selected="selected"'; ?> value="shortcode">Shortcode [wp_twitter]</option>
						<option <?php if(get_option('wp_twitter_where') == 'manual') echo 'selected="selected"'; ?> value="manual">Manual</option>
					</select>
				</td>
			</tr>
			<tr>
				<th scope="row" valign="top">
					Type
				</th>
				<td>
					<div style="float:left; width:32%;">
						<p>
							<input type="radio" value="vertical" <?php if (get_option('wp_twitter_version') == 'vertical') echo 'checked="checked"'; ?> name="wp_twitter_version" id="wp_twitter_version_vertical" group="wp_twitter_version"/>
							<label for="wp_twitter_version_large">Vertical count</label>
						</p>
						<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/tweetv.png" /></p>
					</div>
					<div style="float:left; width:32%;">
						<p>
							<input type="radio" value="horizontal" <?php if (get_option('wp_twitter_version') == 'horizontal') echo 'checked="checked"'; ?> name="wp_twitter_version" id="wp_twitter_version_horizontal" group="wp_twitter_version" />
							<label for="wp_twitter_version_compact">Horizontal count</label>
						</p>
						<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/tweeth.png" /></p>
					</div>
					<div style="float:left; width:32%;">
						<p>
							<input type="radio" value="none" <?php if (get_option('wp_twitter_version') == 'none') echo 'checked="checked"'; ?> name="wp_twitter_version" id="wp_twitter_version_none" group="wp_twitter_version" />
							<label for="wp_twitter_version_compact">No count</label>
						</p>
						<p><img src="<?php echo plugins_url(basename(dirname(__FILE__))); ?>/img/tweetn.png" /></p>
					</div>
				</td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="wp_twitter_style">Styling</label></th>
				<td>
					<input type="text" value="<?php echo htmlspecialchars(get_option('wp_twitter_style')); ?>" name="wp_twitter_style" id="wp_twitter_style" />
					<span class="description">Add style to the div that surrounds the button E.g. <code>float: left; margin-right: 10px;</code></span>
				</td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="wp_twitter_source">Source</label></th>
				<td>
					RT @<input type="text" value="<?php echo get_option('wp_twitter_source'); ?>" name="wp_twitter_source" id="wp_twitter_source" />
					<span class="description">Please use the format of 'yourname', not 'RT @yourname'.</span>
				</td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="wp_twitter_source">Language</label></th>
				<td>
					<select name="wp_twitter_language">
						<option <?php if(get_option('wp_twitter_language') == '') echo 'selected="selected"'; ?> value="">English</option>
						<option <?php if(get_option('wp_twitter_language') == 'fr') echo 'selected="selected"'; ?> value="fr">French</option>
						<option <?php if(get_option('wp_twitter_language') == 'de') echo 'selected="selected"'; ?> value="de">German</option>
						<option <?php if(get_option('wp_twitter_language') == 'es') echo 'selected="selected"'; ?> value="es">Spanish</option>
						<option <?php if(get_option('wp_twitter_language') == 'ja') echo 'selected="selected"'; ?> value="ja">Japanese</option>
					</select>
					<span class="description">The language of the button.</span>
				</td>
			</tr>
			<tr>
				<th scope="row" valign="top"><label for="wp_twitter_source">Tweet-Text</label></th>
				<td>
					<div>
						<input type="radio" value="default" <?php if (get_option('wp_twitter_tweettext') == 'default') echo 'checked="checked"'; ?> name="wp_twitter_tweettext" id="wp_twitter_tweettext_default" group="wp_twitter_tweettext" />
						<label for="wp_twitter_tweettext_default">The title of the page the button is on.</label>
					</div>
					<div>
						<input type="radio" value="own" <?php if (get_option('wp_twitter_tweettext') == 'own') echo 'checked="checked"'; ?> name="wp_twitter_tweettext" id="wp_twitter_tweettext_own" group="wp_twitter_tweettext" />
						<input type="text" value="<?php echo get_option('wp_twitter_tweettext_owntext'); ?>" name="wp_twitter_tweettext_owntext" id="wp_twitter_tweettext_owntext" />
					</div>
					<div>
						<span class="description">This is the text that people will include in their Tweet when they share from your website.</span>
					</div>
				</td>
			</tr>
		</table>
		<p class="submit"><input type="submit" name="Submit" value="<?php _e('Save Changes'); ?>" /></p>
	</form>
</div>
<?php
}

// On access of the admin page, register these variables (required for WP 2.7 & newer)
function wp_twitter_init() {
	if(function_exists('register_setting')) {
		register_setting('wp_twitter-options', 'wp_twitter_display_page');
		register_setting('wp_twitter-options', 'wp_twitter_display_front');
		register_setting('wp_twitter-options', 'wp_twitter_display_feed');
		register_setting('wp_twitter-options', 'wp_twitter_source', 'wp_twitter_sanitize_username');
		register_setting('wp_twitter-options', 'wp_twitter_style');
		register_setting('wp_twitter-options', 'wp_twitter_where');
		register_setting('wp_twitter-options', 'wp_twitter_language');
		register_setting('wp_twitter-options', 'wp_twitter_version');
		register_setting('wp_twitter-options', 'wp_twitter_tweettext');
		register_setting('wp_twitter-options', 'wp_twitter_tweettext_owntext');
	}
}

function wp_twitter_sanitize_username($username) {
	return preg_replace('/[^A-Za-z0-9_]/', '', $username);
}

// Only all the admin options if the user is an admin
if(is_admin()) {
	add_action('admin_menu', 'wp_twitter_options');
	add_action('admin_init', 'wp_twitter_init');
}

// Set the default options when the plugin is activated
function wp_twitter_activate() {
	add_option('wp_twitter_where', 'before');
	add_option('wp_twitter_language', 'de');
	add_option('wp_twitter_source');
	add_option('wp_twitter_style', 'float: right; margin-left: 10px;');
	add_option('wp_twitter_display_page', '1');
	add_option('wp_twitter_display_front', '0');
	add_option('wp_twitter_display_feed', '0');
	add_option('wp_twitter_version', 'vertical');
	add_option('wp_twitter_tweettext', 'default');
	add_option('wp_twitter_tweettext_owntext', '');
}

add_filter('the_content', 'wp_twitter_update', 8);
add_filter('get_the_excerpt', 'wp_twitter_remove_filter', 9);

add_action('wp_head', 'wp_twitter_head');

register_activation_hook(__FILE__, 'wp_twitter_activate');
?>